# SomeHexTools.py
# 1110-profs
# March 2, 2016
""" Graphics procedures that can be used to draw hexagons and
honeycombs.
"""

from SimpleGraphics import *
from math import sqrt

def DrawHexCell(a,b,FillColor=None):
    """
    Displays a regular hexagon with side one and center (a,b).
    The hexagon is colored according to FillColor.
    
    PreC: a and b are numbers, FillColor is an rgb list.
    """
    alfa = sqrt(3)/2
    x = [a+.5,    a-.5,   a-1,  a-.5 ,  a+.5,  a+1]
    y = [b+alfa,  b+alfa, b,       b-alfa, b-alfa, b]
    DrawPoly(x,y,FillColor,EdgeWidth=2,EdgeColor=RED)
    DrawDisk(a,b,.05,FillColor=BLACK)


    
def NeighborCenter(a,b,i):
    """ Returns floats u and v with the property that
        (u,v) is the center of the i-th hex-cell neighbor.

        Example. If a, b, and i are initialized and 
                       
                  u,v = NeighborCenter(a,b,i)

        then u and v would respectively be assigned the x and y
        coordinates of the center of the second neighbor of the
        hex-cell centered at (a,b).
     
        PreC: a and b are floats and (a,b) is the center of a hex-cell. 
        i is an int that satisfies 1<=i<=6.
    """
    alfa = 1.5
    beta = sqrt(3)/2
    if i==1:
        u = a; v = b+2*beta
    elif i==2:
        u = a+alfa; v = b+beta
    elif i==3:
        u = a+alfa; v = b-beta
    elif i==4:
        u = a; v = b-2*beta
    elif i==5:
        u = a-alfa; v = b-beta
    else:
        u = a-alfa; v = b+beta
    return u,v
        


if __name__ == '__main__':
 
    # Draw a single hexagon...
    m = 6
    MakeWindow(m,bgcolor=WHITE,labels=True)
    DrawHexCell(0,0,FillColor=YELLOW)
    x,y = NeighborCenter(0,0,2)
    DrawHexCell(x,y,FillColor=BLUE)
    #  = NeighborCenter(     )
    DrawHexCell(x,y,FillColor=MAGENTA)
    #  = NeighborCenter(     )
    DrawHexCell(x,y,FillColor=GREEN)
    x,y = NeighborCenter(0,0,5)
    DrawHexCell(x,y,FillColor=RED)
    #    = NeighborCenter(     )
    DrawHexCell(x,y,FillColor=CYAN)
    #    = NeighborCenter(     )
    DrawHexCell(x,y,FillColor=ORANGE)
    
    ShowWindow()

